aboutsummaryrefslogtreecommitdiff
path: root/engines/sci/engine/script.h
diff options
context:
space:
mode:
authorFilippos Karapetis2012-06-23 21:20:43 +0300
committerFilippos Karapetis2012-06-23 21:45:24 +0300
commitc1eb93bc5a9866787f27add5ca1d821e1470a4be (patch)
tree96faac1ed45d97f53f1b01da1d6a6dcf1609663a /engines/sci/engine/script.h
parentc075aafddb0dba00878f6382a6e277dbaab45e10 (diff)
downloadscummvm-rg350-c1eb93bc5a9866787f27add5ca1d821e1470a4be.tar.gz
scummvm-rg350-c1eb93bc5a9866787f27add5ca1d821e1470a4be.tar.bz2
scummvm-rg350-c1eb93bc5a9866787f27add5ca1d821e1470a4be.zip
SCI: Clean up validateExportFunc() and related functions
Also renamed some SCI3 related code to indicate when it's SCI3 specific
Diffstat (limited to 'engines/sci/engine/script.h')
-rw-r--r--engines/sci/engine/script.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/engines/sci/engine/script.h b/engines/sci/engine/script.h
index 0c99f13235..9747f072c5 100644
--- a/engines/sci/engine/script.h
+++ b/engines/sci/engine/script.h
@@ -197,11 +197,11 @@ public:
* Validate whether the specified public function is exported by
* the script in the specified segment.
* @param pubfunct Index of the function to validate
* @param relocate Decide whether to relocate this public function or not
* @return NULL if the public function is invalid, its
* offset into the script's segment otherwise
*/
- uint16 validateExportFunc(int pubfunct, bool relocate);
+ uint16 validateExportFunc(int pubfunct, bool relocateSci3);
/**
* Marks the script as deleted.
@@ -249,7 +249,7 @@ public:
/**
* Gets an offset to the beginning of the code block in a SCI3 script
*/
- int getCodeBlockOffset() { return READ_SCI11ENDIAN_UINT32(_buf); }
+ int getCodeBlockOffsetSci3() { return READ_SCI11ENDIAN_UINT32(_buf); }
private:
/**
@@ -197,11 +197,11 @@ public:
* the script in the specified segment.
* @param pubfunct Index of the function to validate
- * @param relocate Decide whether to relocate this public function or not
+ * @param relocateSci3 Decide whether to relocate this SCI3 public function or not
* @return NULL if the public function is invalid, its
* offset into the script's segment otherwise